@@ -1,5 +1,6 @@
 library(FixedPoint)
 library(testthat)
+library(SQUAREM)
 context("Pricing a Perpetual American Put.")
 
 # Consider a perpetual American put option. It never expires unless it is excercised. There is a
@@ -47,8 +48,9 @@ IterateOnce = function(OptionPrice){
   return(OptionPrice)
 }
 
-Test_Of_Convergence = function(Function = IterateOnce, Inputs = OptionPrice, Outputs = c(), Method = c("Newton") , ConvergenceMetric  = function(Resids){max(abs(Resids))} , ConvergenceMetricThreshold = 1e-10, MaxIter = 1e3, MaxM = 10, Dampening = 1, PrintReports = TRUE, ReportingSigFig = 5, ConditionNumberThreshold = 1e10){
+Test_Of_Convergence = function(Function = IterateOnce, Inputs = OptionPrice, Outputs = c(), Method = c("Newton") , ConvergenceMetric  = function(Resids){max(abs(Resids))} , ConvergenceMetricThreshold = 1e-10, MaxIter = 1e3, MaxM = 10, Dampening = 1, PrintReports = FALSE, ReportingSigFig = 5, ConditionNumberThreshold = 1e10){
   A = FixedPoint(Function = Function, Inputs = Inputs, Method = Method, ConvergenceMetric = ConvergenceMetric, ConvergenceMetricThreshold = ConvergenceMetricThreshold, MaxIter = MaxIter, MaxM = MaxM, Dampening = Dampening, PrintReports = PrintReports, ReportingSigFig = ReportingSigFig)
+  cat(paste0("The ", Method, " method took ", length(A$Convergence), " iterations and finished with convergence of ", A$Finish, "\n"))
   return(A$Convergence[length(A$Convergence)] < ConvergenceMetricThreshold)
 }
 
@@ -62,5 +64,8 @@ test_that("Testing that each method converges in the quadratic case to within to
   expect_true(Test_Of_Convergence(Method = "MPE"))      # This takes 43  iterations and will not normally be run
   expect_true(Test_Of_Convergence(Method = "RRE"))      # This takes 52  iterations and will not normally be run
 })
-
-
+Func = IterateOnce
+Inputs = OptionPrice
+sqm = SQUAREM::squarem(Inputs,Func, control=list(tol= 1e-10*4 ))
+convergence = sum(abs(sqm$par - Func(sqm$par) ))
+cat(paste0("The squarem method took ", sqm$fpevals, " iterations and finished with convergence of ", convergence, "\n")) # This takes 103 iterations.
